"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AjaxHelper = void 0;
var https = require("https");
var Q = require("q");
var utilities_1 = require("./utilities");
var url = require("url");
var contentLength = "content-length";
var defaultPort = 443;
var AjaxHelper;
(function (AjaxHelper) {
    /**
     * Forward the passed in request to the passed in host and returns the response.
     *
     * @param request The incoming request to forward.
     * @param host The target host.
     * @param port The target host port.
     * @return A promise that will resolve with the response body from the forwarded request.
     */
    function fwdAjax(request, host, port) {
        if (port === void 0) { port = defaultPort; }
        return ajaxHelper(request, host, port);
    }
    AjaxHelper.fwdAjax = fwdAjax;
    /**
     * Forwards the request back to the same host but a different path.
     *
     * @param request The incoming request to forward.
     * @param port The target host port.
     * @param method The forward request method.
     * @return A promise that will resolve with the response body from the forwarded request.
     */
    function loopbackAjax(request, path, method) {
        var hostAndPort = request.get("host").split(":");
        return ajaxHelper(request, hostAndPort[0], hostAndPort.length === 2 ? Number(hostAndPort[1]) : defaultPort, path, method);
    }
    AjaxHelper.loopbackAjax = loopbackAjax;
    /**
     * Gets the JSON data from the body of the response. If it fails to parse as valid JSON, the original data will be returned.
     *
     * @param response The response object.
     * @return A promise that is resolved with the data.
     */
    function getJsonData(response) {
        var defered = Q.defer();
        var chunkStr = "";
        response.on("data", function (chunk) {
            //chunkStr += chunk.toString("utf-8");
            chunkStr += chunk;
        });
        response.on("end", function () {
            var response;
            try {
                response = JSON.parse(chunkStr);
            }
            catch (err) {
                // console.error("getJsonData: Error getting response data. " + JSON.stringify(err));
            }
            defered.resolve(response);
        });
        return defered.promise;
    }
    AjaxHelper.getJsonData = getJsonData;
    function ajaxHelper(request, host, port, path, method) {
        var defered = Q.defer();
        method = method || request.method;
        path = path || request.originalUrl;
        var ajaxWorker = function (err, bodyContent) {
            if (err) {
                defered.reject(err);
            }
            var headers = headersToProxy(request);
            headers[contentLength] = bodyContent ? ("" + bodyContent.length) : "0";
            var outgoingRequest = https.request({
                host: host,
                port: port,
                path: path,
                method: method,
                headers: headers,
            }, function (res) {
                defered.resolve(res);
            });
            outgoingRequest.on("error", function (err) {
                defered.reject(err);
            });
            if (bodyContent) {
                outgoingRequest.write(bodyContent);
            }
            outgoingRequest.end();
        };
        if (method === "POST") {
            if (typeof request.body === 'object')
                ajaxWorker(null, JSON.stringify(request.body));
            else
                defered.reject(new Error('only object of request body is acceptable'));
        }
        else {
            ajaxWorker(null, null);
        }
        return defered.promise;
    }
    function headersToProxy(request) {
        var knownHeaders = [
            "authorization",
            "content-type"
        ];
        if (!request || !request.headers) {
            return null;
        }
        var headers = {};
        utilities_1.Utilities.forEachKey(request.headers, function (key, val) {
            if (knownHeaders.indexOf(key.toLowerCase()) >= 0) {
                headers[key] = val;
            }
        });
        return headers;
    }
})(AjaxHelper = exports.AjaxHelper || (exports.AjaxHelper = {}));
//# sourceMappingURL=ajaxHelper.js.map