"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RdfeManager = void 0;
var Q = require("q");
var rdfeHelper_1 = require("./rdfeHelper");
var utilities_1 = require("../Helpers/utilities");
var RdfeManager;
(function (RdfeManager) {
    "use strict";
    /**
     * The mock rdfe manager
     */
    var Manager = /** @class */ (function () {
        function Manager() {
            this.data = {};
        }
        /**
         * Initializes the mock data. Call this with empty data to reset state.
         *
         * @param data The mock data.
         * @return A promise that is resolved when the data is initialized.
         */
        Manager.prototype.initializeMockData = function (data) {
            this.data = rdfeHelper_1.RdfeHelper.cloneObject(data || {});
            return Q.resolve(true);
        };
        /**
         * Gets the list of mock subscriptions.
         */
        Manager.prototype.getSubscriptions = function () {
            return (this.data.subscriptions || []);
        };
        /**
         * Gets a subscription based on id from the mock data.
         *
         * @param subscriptionId The subscription GUID/ID.
         */
        Manager.prototype.getSubscription = function (subscriptionId) {
            subscriptionId = subscriptionId.toLowerCase();
            return utilities_1.Utilities.findInArr(this.getSubscriptions(), function (sub) { return sub.subscriptionId.toLowerCase() === subscriptionId; });
        };
        /**
         * The Add Management Certificate operation adds a management certificate to the specified subscription.
         *
         * @param subscriptionId The subscription GUID/ID.
         * @param certificate The SubscriptionCertificate to add.
         * @returns false if the subscription doesn't exist,
         *          false if the certificate already exists for the given subscription id,
         *          true if the certificate was successfully added.
         */
        Manager.prototype.addManagementCertificate = function (subscriptionId, subscriptionCertificate) {
            if (!this.getSubscription(subscriptionId)) {
                return false;
            }
            if (this.getManagementCertificate(subscriptionId, subscriptionCertificate.subscriptionCertificateThumbprint)) {
                return false;
            }
            if (subscriptionId in this.data.certificates) {
                this.data.certificates[subscriptionId].push(subscriptionCertificate);
            }
            else {
                this.data.certificates[subscriptionId] = [subscriptionCertificate];
            }
            return true;
        };
        /**
         * The Delete Management Certificate operation deletes a certificate from the specified subscription.
         *
         * @param subscriptionId The subscription GUID/ID.
         * @param thumbprint The thumbprint of the SubscriptionCertificate to delete.
         * @returns false if the subscription doesn't exist,
         *          false if the certificate doiesn't exist for the given subscription id,
         *          true if the certificate was successfully deleted.
         */
        Manager.prototype.deleteManagementCertificate = function (subscriptionId, thumbprint) {
            if (!this.getSubscription(subscriptionId)) {
                return false;
            }
            if (!this.getManagementCertificate(subscriptionId, thumbprint)) {
                return false;
            }
            if (subscriptionId in this.data.certificates) {
                this.data.certificates[subscriptionId] = this.data.certificates[subscriptionId].filter(function (certificate) {
                    return certificate.subscriptionCertificateThumbprint !== thumbprint;
                });
            }
            return true;
        };
        /**
         * The Get Management Certificate operation retrieves information about the management certificate with the specified thumbprint.
         *
         * @param subscriptionId The subscription GUID/ID.
         * @param thumbprint The thumbprint of the SubscriptionCertificate to retrieve.
         */
        Manager.prototype.getManagementCertificate = function (subscriptionId, thumbprint) {
            if (!this.getSubscription(subscriptionId)) {
                return null;
            }
            if (subscriptionId in this.data.certificates) {
                for (var _i = 0, _a = this.data.certificates[subscriptionId]; _i < _a.length; _i++) {
                    var certificate = _a[_i];
                    if (certificate.subscriptionCertificateThumbprint === thumbprint) {
                        return certificate;
                    }
                }
            }
            return null;
        };
        /**
         * The List Management Certificates operation returns basic information about all of the management certificates that are associated with the specified subscription.
         *
         * @param subscriptionId The subscription GUID/ID.
         */
        Manager.prototype.listManagementCertificates = function (subscriptionId) {
            return this.data.certificates[subscriptionId.toLowerCase()] || [];
        };
        return Manager;
    }());
    RdfeManager.Manager = Manager;
})(RdfeManager = exports.RdfeManager || (exports.RdfeManager = {}));
//# sourceMappingURL=rdfeManager.js.map